const express = require('express');
const passport = require('passport');
const session = require('express-session');
const Sequelize = require('sequelize');
const bodyParser = require('body-parser');
const flash = require('connect-flash');

const app = express();

app
  .use(express.static('public'))
  .use(session({ secret: 'cats', resave: false, saveUninitialized: false }))
  .use(bodyParser.urlencoded({ extended: false }))
  .use(passport.initialize())
  .use(passport.session())
  .use(flash());

const sequelize = require('./getSequelizeSync');

sequelize
  .authenticate()
  .then(() => {
    console.log('Connexion à postgre réussie.');

    const User = require('./models/user')(sequelize, Sequelize.DataTypes);

    passport.use(require('./getLocalStrategy')(User));

    passport.serializeUser((user, done) => {
      done(null, user.id);
    });
    passport.deserializeUser((id, done) => {
      User
        .findByPk(id)
        .then(user => done(null, user))
        .catch(err => done(err, false));
    });

    routage(User);
  })

function routage(User) {
  app
    .use('/', require('./routes/login')(passport))
    .use('/', require('./routes/register')(User))
    .use('/', require('./routes/root'))
    .use('/', require('./routes/logout'))
    .get('/user', routeGuard, (req, res) => {
      res.send('user');
    })
    .listen(3000, () => {
      console.log('Site en ligne');
    });
}

function routeGuard(req, res, next) {
  if (req.user) {
    next();
  } else {
    res.redirect('/login');
  }
}